@@ -1,12 +1,12 @@
-# $Id: installer.rb,v 1.18 2004/03/05 17:22:56 sdalu Exp $
+# $Id: installer.rb,v 1.21 2010/06/21 07:30:27 chabannf Exp $
 
 # 
 # CONTACT     : zonecheck@nic.fr
 # AUTHOR      : Stephane D'Alu <sdalu@nic.fr>
 #
 # CREATED     : 2003/10/23 21:04:09
-# REVISION    : $Revision: 1.18 $ 
-# DATE        : $Date: 2004/03/05 17:22:56 $
+# REVISION    : $Revision: 1.21 $ 
+# DATE        : $Date: 2010/06/21 07:30:27 $
 #
 
 
@@ -15,7 +15,7 @@ include FileUtils
 
 
 class Installer
-    CVS_NAME	= %q$Name: ZC-2_0_4 $
+    CVS_NAME	= %q$Name: ZC-3_0_2 $
     VERSION	= (Proc::new { 
 		       n = CVS_NAME.split[1]
 		       n = /^ZC-(.*)/.match(n) unless n.nil?
@@ -26,7 +26,8 @@ class Installer
 		   }).call
 
     def initialize
-	interpreter = ENV['SUDO_COMMAND'] || ENV['_']
+  interpreter = `which ruby`
+	interpreter ||= ENV['SUDO_COMMAND'] || ENV['_']
 	if RUBY_PLATFORM =~ /mswin32/ 
 	    require 'Win32API'
 	    getcli = Win32API::new('kernel32', "GetCommandLine", [], 'P')
@@ -41,7 +42,6 @@ class Installer
 	    else false
 	    end
 	}
-
 	ENV['RUBY'      ] ||= interpreter || 'ruby'
 	ENV['PREFIX'    ] ||= '/usr/local'
 	ENV['PROGNAME'  ] ||= 'zonecheck'
@@ -55,7 +55,7 @@ class Installer
 	ENV['DOCDIR'    ] ||= "#{ENV['PREFIX']}/share/doc"
 	ENV['ETCDIR'    ] ||= "#{ENV['PREFIX']}/etc"
 	ENV['CGIDIR'    ] ||= "#{ENV['LIBEXEC']}/#{ENV['PROGNAME']}/cgi-bin"
-        ENV['WWWDIR'    ] ||= "#{ENV['LIBEXEC']}/#{ENV['PROGNAME']}/www"
+  ENV['WWWDIR'    ] ||= "#{ENV['LIBEXEC']}/#{ENV['PROGNAME']}/www"
 
 	ENV['VERSION'	] ||= VERSION
 
@@ -177,7 +177,7 @@ class Installer
 
     def patch_cgi
 	puts "==> Patching HTML pages"
-	Dir["#{@ch_wwwdir}/www/html/*.html.*"].each { |page|
+	Dir["#{@ch_wwwdir}/html/*.html.*"].each { |page|
 	    page_content = File.readlines(page)
 	    page_content.each { |line| 
 		line.gsub!(/HTML_PATH/, ENV['HTML_PATH']) }
