@@ -1,25 +1,25 @@
 #!/usr/local/bin/ruby
-# $Id: zc.rb,v 1.123 2004/01/26 13:25:24 sdalu Exp $
+# $Id: zc.rb,v 1.127 2010/06/29 12:08:35 chabannf Exp $
 
 # 
 # CONTACT     : zonecheck@nic.fr
 # AUTHOR      : Stephane D'Alu <sdalu@nic.fr>
 #
 # CREATED     : 2002/07/18 10:29:53
-# REVISION    : $Revision: 1.123 $ 
-# DATE        : $Date: 2004/01/26 13:25:24 $
+# REVISION    : $Revision: 1.127 $ 
+# DATE        : $Date: 2010/06/29 12:08:35 $
 #
 # CONTRIBUTORS: (see also CREDITS file)
 #
 #
-# LICENSE     : GPL v2 (or MIT/X11-like after agreement)
+# LICENSE     : GPL v3
 # COPYRIGHT   : AFNIC (c) 2003
 #
 # This file is part of ZoneCheck.
 #
 # ZoneCheck is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 # 
 # ZoneCheck is distributed in the hope that it will be useful, but
@@ -82,8 +82,6 @@ ZC_DEFAULT_INPUT	= 'cli'
 ZC_CGI_ENV_KEYS		= [ 'GATEWAY_INTERFACE', 'SERVER_ADDR' ]
 ZC_CGI_EXT		= 'cgi'
 
-ZC_GTK_ENV_KEYS		= [] #[ 'DISPLAY' ]
-
 ## Publisher
 ZC_HTML_PATH		= ENV['ZC_HTML_PATH'] || "#{ZC_INSTALL_PATH}/www"
 
@@ -103,7 +101,7 @@ ZC_IP_STACK		= ENV['ZC_IP_STACK'] || '46'
 #
 # Identification
 #
-ZC_CVS_NAME	= %q$Name: ZC-2_0_4 $
+ZC_CVS_NAME	= %q$Name: ZC-3_0_2 $
 ZC_NAME		= 'ZoneCheck'
 ZC_VERSION	= (Proc::new { 
 		       n = ZC_CVS_NAME.split[1]
@@ -141,7 +139,7 @@ end
 #
 # Run at safe level 1
 #  A greater safe level is unfortunately not possible due to some 
-#  low level operations in the NResolv library
+#  low level operations in the Dnsruby library
 #
 $SAFE = 0	# REXML BUG
 
@@ -178,8 +176,7 @@ $zc_custom	||= 'zc-custom'
 $zc_xml_parser	||= ZC_XML_PARSER
 
 # Resolver configuration
-$nresolv_rootserver_hintfile	= "#{$zc_config_dir}/rootservers"
-$nresolv_dbg			= 0x0000
+$rootserver_hintfile	= "#{$zc_config_dir}/rootservers"
 
 
 #
@@ -188,30 +185,56 @@ $nresolv_dbg			= 0x0000
 # Standard Ruby libraries
 require 'socket'
 
-# External libraries
-require 'nresolv'
-
 # Modification to standard/core ruby classes
 require 'ext/array'
 require 'ext/file'
 require 'ext/myxml'
 
+
 # ZoneCheck component
-require 'dbg'
 require 'locale'
 require 'msgcat'
 require 'console'
 require 'zonecheck'
+require 'dbg'
 
 
 #
 # Debugger object
 #  (earlier initialization, can also be set via input interface)
 #
-$dbg       = DBG::new
+$dbg       = ZoneCheck::DBG::new
 $dbg.level = ENV['ZC_DEBUG'] if ENV['ZC_DEBUG']
 
 
+# External libraries
+begin 
+  require 'dnsruby'
+rescue LoadError => e
+  begin 
+    require 'rubygems'
+  rescue LoadError => e
+    $dbg.msg(ZoneCheck::DBG::INIT, "Unable to require rubygems (#{e})")
+    $stderr.puts "ERROR: You have to install Dnsruby in order to execute ZoneCheck"
+    exit EXIT_ERROR
+  end
+  begin 
+    require 'dnsruby'
+  rescue LoadError => e
+    $dbg.msg(ZoneCheck::DBG::INIT, "Unable to require dnsruby (#{e})")
+    $stderr.puts "ERROR: You have to install Dnsruby in order to execute ZoneCheck"
+    exit EXIT_ERROR
+  end
+end
+
+if Dnsruby.version < 1.47
+  $dbg.msg(ZoneCheck::DBG::INIT, "Unable to require dnsruby (#{e})")
+  $stderr.puts "ERROR: You have to install at least Dnsruby 1.47 in order to execute ZoneCheck"
+  exit EXIT_ERROR
+end
+
+include ZoneCheck
+
 #
 # XML parser
 #
@@ -255,8 +278,10 @@ $ipv6_stack &&= begin
 #        present in the code (except for debugging purpose)
 #
 begin
+    $supported_languages = ["en","fr"]
+  
     # Initialize locale
-    $locale = Locale::new
+    $locale = ZoneCheck::Locale::new
     $locale.lang = ZC_LANG_DEFAULT if $locale.lang.nil?
     
     # Initialize the console
@@ -295,21 +320,21 @@ rescue LoadError => e
 end
 
 
-#
-# Adjustement due to zc-custom
-#
-begin
-    hintfile = "#{$zc_config_dir}/rootservers"
-    if $nresol_rootserver_hintfile != hintfile
-	NResolv::DNS::RootServer.current = NResolv::DNS::RootServer.from_hintfile(hintfile)
-    end
-rescue YAML::ParseError, SystemCallError => e
-    $dbg.msg(DBG::INIT, 
-	    "Unable to read/parse rootserver hint file (#{e})")
-end
+# XXX
+## Adjustement due to zc-custom
+##
+#begin
+#    hintfile = "#{$zc_config_dir}/rootservers"
+#    if $rootserver_hintfile != hintfile
+#	NResolv::DNS::RootServer.current = NResolv::DNS::RootServer.from_hintfile(hintfile)
+#    end
+#rescue YAML::ParseError, SystemCallError => e
+#    $dbg.msg(DBG::INIT, 
+#	    "Unable to read/parse rootserver hint file (#{e})")
+#end
 
 
 #
 # Check it now!
 #
-exit ZoneCheck::new::start ? EXIT_OK : EXIT_FAILED
+exit ZoneCheck::ZoneCheck::new::start ? EXIT_OK : EXIT_FAILED
